/**
 * @public
 */
export declare interface AdapterOptions {
    prism: PrismjsOptions;
    hljs: HljsOptions;
    enableCodeLineNumber: boolean;
    enableMacStyle: boolean;
}

declare interface Attribute {
    name: string;
    value: string;
}

/**
 * @public
 */
export declare abstract class BaseHighlighter {
    private _themeHref?;
    private _isDarkTheme;
    constructor();
    get enableCodeLineNumber(): boolean;
    get adapterOptions(): AdapterOptions;
    get enableMacStyle(): boolean;
    get isDarkTheme(): boolean;
    get linesHighlightedClassToken(): string;
    abstract get id(): HighlighterId;
    abstract get highlighterOptions(): IHighlighterOptions;
    abstract highlight(el: HTMLElement): Promise<void>;
    abstract ensureResourcesLoaded(): Promise<void>;
    abstract highlightLines(el: HTMLElement): number[];
    highlightAllUnder(parentEl: HTMLElement | string, beforeHighlightBlock?: (preEl: HTMLElement, codeEl: HTMLElement) => boolean, afterHighlightBlock?: (preEl: HTMLElement, codeEl: HTMLElement) => void | Promise<void>): Promise<void>;
    setTheme(theme?: string, attributes?: Attribute[], isDarkTheme?: boolean): Promise<void>;
    protected resolveContainerElements(el: HTMLElement): [HTMLPreElement, HTMLElement] | undefined;
    protected loadStyles(attributes?: Attribute[]): Promise<void>;
    protected tryApplyLang(el: HTMLElement): string;
    protected onHighlighting(engine: HighlighterId, preEl: HTMLPreElement, codeEl: HTMLElement): void;
    protected onHighlighted(engine: HighlighterId, preEl: HTMLPreElement, codeEl: HTMLElement): void;
    protected setEngineClassToken(engine: HighlighterId, preEl: HTMLPreElement): void;
    protected removeLinesHighlightedClassToken(...els: HTMLElement[]): void;
    /**
     * 过滤code元素中的内容, e.g. 移除行号元素, html标签等
     * @param el
     */
    protected filterCodeContent(el: HTMLElement): string;
    protected removeLinkElements(selector: string): void;
    protected resolveLinesToHighlight(el: HTMLElement): number[] | undefined;
    private setIsDarkTheme;
    private setBodyClass;
}

/**
 * @public
 */
export declare const CnblogsPresetAdapterOptions: AdapterOptions;

/**
 * @public
 */
export declare const DefaultAdapterOptions: AdapterOptions;

/**
 * @public
 */
export declare type HighlighterId = 'prismjs' | 'highlight.js';

/**
 * @public
 */
export declare class HighlightersFactory {
    static configCodeHighlightOptions(options: Partial<AdapterOptions>): void;
    static useCnblogsCodeHighlightOptions(): void;
    static createCodeHighlighter(engine: HighlighterId, theme: {
        name: string;
        isDark: boolean;
    } | string, options?: Partial<AdapterOptions>): HljsHighlighter | PrismHighlighter;
}

/**
 * @public
 */
export declare class HljsHighlighter extends BaseHighlighter {
    private _linkAttr;
    get highlighterOptions(): IHighlighterOptions;
    get id(): HighlighterId;
    get linesHighlightedClassToken(): string;
    get enableCodeLineNumber(): boolean;
    ensureResourcesLoaded(): Promise<void>;
    highlight(el: HTMLElement): Promise<void>;
    highlightLines(preEl: HTMLPreElement): number[];
    private loadHljs;
    private loadLineNumberPlugin;
}

/**
 * @public
 */
export declare interface HljsOptions extends IHighlighterOptions {
}

/**
 * @public
 */
export declare interface IHighlighterOptions {
    scriptPath: string;
    lineNumberPluginPath?: string;
    stylesheets: {
        tagId: string;
        href: string;
    }[];
    themeBaseUrl: string;
    defaultTheme: string;
}

/**
 * @public
 */
export declare class PrismHighlighter extends BaseHighlighter {
    private _linkAttr;
    get highlighterOptions(): IHighlighterOptions;
    get id(): HighlighterId;
    get enableCodeLineNumber(): boolean;
    highlight(el: HTMLElement): Promise<void>;
    highlightLines(preEl: HTMLPreElement): number[];
    ensureResourcesLoaded(): Promise<void>;
    setTheme(theme?: string, attributes?: Attribute[], isDarkTheme?: boolean): Promise<void>;
    private loadPrismAsync;
    private loadPrismAutoLoader;
    private loadPrismLineNumberPluginScript;
    private loadPrismLineNumberPluginStyle;
}

/**
 * @public
 */
export declare interface PrismjsOptions extends IHighlighterOptions {
    autoLoaderPluginPath: string;
    lineNumberStylePath?: string;
}

export { }
