import { CnblogsPresetAdapterOptions } from './highlighter-option';
import { HljsHighlighter } from './hljs-highlighter';
import { PrismHighlighter } from './prism-highlighter';
import { AdapterOptionsProvider } from './adapter-options-provider';
/**
 * @public
 */
var HighlightersFactory = /** @class */ (function () {
    function HighlightersFactory() {
    }
    HighlightersFactory.configCodeHighlightOptions = function (options) {
        AdapterOptionsProvider.set(options);
    };
    HighlightersFactory.useCnblogsCodeHighlightOptions = function () {
        this.configCodeHighlightOptions(CnblogsPresetAdapterOptions);
    };
    HighlightersFactory.createCodeHighlighter = function (engine, theme, options) {
        if (options)
            this.configCodeHighlightOptions(options);
        var highlighter;
        switch (engine) {
            case 'highlight.js':
                highlighter = new HljsHighlighter();
                break;
            case 'prismjs':
                highlighter = new PrismHighlighter();
                break;
            default:
                throw Error('unknown highlight engine');
        }
        if (!theme)
            theme = highlighter.highlighterOptions.defaultTheme;
        var themeName = typeof theme === 'string' ? theme : theme.name;
        var isDark = typeof theme === 'string' ? false : theme.isDark;
        highlighter.setTheme(themeName, undefined, isDark).then();
        return highlighter;
    };
    return HighlightersFactory;
}());
export { HighlightersFactory };
